@@ -112,10 +112,6 @@ gsf_init (void)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
 
-#if !GLIB_CHECK_VERSION(2,36,0)
-	g_type_init ();
-#endif
-
 #ifdef _GSF_GTYPE_THREADING_FIXED
 	if (NULL == static_type_module) {
 		static_type_module = g_object_new (gsf_dummy_type_module_get_type(), NULL);
@@ -704,6 +700,8 @@ gsf_base64_decode_simple (guint8 *data, size_t len)
 }
 
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 /* Largely a copy of g_object_new_valist.  */
 /**
  * gsf_property_settings_collect_valist:
@@ -823,6 +821,7 @@ gsf_property_settings_free (GParameter *params,
 		g_value_unset (&params[n_params].value);
 	g_free (params);
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 
 
